
local AddonName, NS = ...
--------------------------------------------------- Initialise Defaults --------------------------------------------------
local Defaults = {
	WorldViewFrame = {
		setpoint = { [1]="TOP", [2]=UIParent, [3]="TOP", [4]=0, [5]=-35 },
		grid = {
			initspacing = 10,
			colors = {
				Centers = { 1, 0, 0 },
				EndPoints = { 0.86, 0.56, 1, 0.6 },
				Highlight = { 0, 1, 0 },
				Lines = { 0, 0, 0 },
				Texts = { 0.8, 0.6, 0 },
			},
		},
	},
--	ViewPort={
--	},
}

local TopLeft = { "TOPLEFT", 10, -15 }
local GridOptionsTopLeft = { "TOPLEFT", 35, -15 }

local HighStrata = "TOOLTIP"

if not DART_Settings.WorldViewFrame then
	DART_Settings.WorldViewFrame = {}
	DL_Copy_Table(Defaults.WorldViewFrame, DART_Settings.WorldViewFrame)
end

local DartSettings = DART_Settings.WorldViewFrame

------------------------------------------------------------------------------------------------------------------
--						  World View Frame						--
------------------------------------------------------------------------------------------------------------------

local WVButton, SaveIndex

local function MoveDartOptions(self, pinned)
	if not self.DartControls then
		self.DartControls = {}
		self.DartControls.list = DART_BaseOptions_SelectTexture
		self.DartControls.x = DART_TextureOptions_XOffset1
		self.DartControls.y = DART_TextureOptions_YOffset1
		self.DartControls.headerx = DART_AnchorHeader_X
		self.DartControls.headery = DART_AnchorHeader_Y
		self.DartControls.hide = DART_TextureOptions_Hide
		self.DartControls.width = DART_TextureOptions_Width
		self.DartControls.height = DART_TextureOptions_Height
		self.DartControls[1] = DART_TextureOptions_NudgeDown
		self.DartControls[2] = DART_TextureOptions_NudgeUp
		self.DartControls[3] = DART_TextureOptions_NudgeRight
		self.DartControls[4] = DART_TextureOptions_NudgeLeft
		self.DartPoints = {}
		self.DartParents = {}
		for k, v in pairs(self.DartControls) do
			self.DartPoints[k] = { v:GetPoint(1) }
			self.DartParents[k] = v:GetParent()
		end
		self.DART_ScrollParent = DART_ScrollMenu.checkParent
	end
	local TP = self.ToggleMovers.Panel
	for k, v in pairs(self.DartControls) do
		v:ClearAllPoints()
	end
	
	if DART_Options_WorldView:IsShown() then
		SaveIndex = DART_NUDGE_INDEX
		DART_NUDGE_INDEX = 1
	else
		DART_NUDGE_INDEX = SaveIndex
	end
	for k, v in pairs(self.DartControls) do
--		if DART_Options_WorldView:IsShown() or pinned then
		if not DART_Options_WorldView:IsShown() or pinned then
			v:SetPoint(unpack(self.DartPoints[k]))
			v:SetParent(self.DartParents[k])
			if v == DART_BaseOptions_SelectTexture then
				v.Label:Show()
				DART_ScrollMenu.checkParent = self.DART_ScrollParent
			end

		else
			if v == DART_BaseOptions_SelectTexture then
				v:SetPoint("BOTTOM", TP, 0, 5)
				v.Label:Hide()
				DART_ScrollMenu.checkParent = TP
			elseif v == DART_TextureOptions_Hide then
				v:SetPoint("TOPLEFT", TP, "TOPLEFT", 5, -15)
			elseif v == DART_TextureOptions_Width then
				v:SetPoint("BOTTOM", self.DartControls.height, "TOP", 0, 10)
			elseif v == DART_TextureOptions_Height then
				v:SetPoint("BOTTOMLEFT", self.DartControls.list, "TOPLEFT", 0, 10)
			elseif v == DART_TextureOptions_XOffset1 then
				v:SetPoint("TOPRIGHT", TP, "TOPRIGHT", -5, -10)
			elseif v == DART_TextureOptions_YOffset1 then
				v:SetPoint("TOPRIGHT", self.DartControls.x, "BOTTOMRIGHT", 0, -2)
			elseif v == DART_AnchorHeader_X then
				v:SetPoint("RIGHT", self.DartControls.x, "LEFT", -5, 0)
			elseif v == DART_AnchorHeader_Y then
				v:SetPoint("RIGHT", self.DartControls.y, "LEFT", -5, 0)
			elseif k == 1 then
				v:SetPoint("TOPRIGHT", TP, "TOPRIGHT", -65, -15)
			else
				v:SetPoint("RIGHT", self.DartControls[k-1], "LEFT", -4, 0)
			end
			v:SetParent(TP)
--		else
		end
	end
end

local function SetProfileText(self)
	self.Profile:SetText("|cffe69900[|r"..DART_INDEX.."|cffe69900]|r") 
end

local function WorldViewOnHide(self, pinned)
	MoveDartOptions(self, pinned)
	WVButton:GetParent():Show() 
end

local function WorldViewOnShow(self, pinned)
	SetProfileText(self)
	MoveDartOptions(self, pinned)
	WVButton:GetParent():Hide() 
end

local function CreateBackground(bgfile, name, parent, height, width)
	local backdrop = {
		bgFile = bgfile,
		edgeFile = "",
		tile = true, 
		edgeSize = 32, 
		tileSize = 32, 
		insets = {
			left = 0,
			right = 0,
			top = 0,
			bottom = 0,
		},
	}
	local f = CreateFrame("Frame", name, parent, BackdropTemplateMixin and "BackdropTemplate")
	f:SetBackdrop(backdrop)
	if width then
		f:SetSize(width, height)	
		DartSettings.setpoint[2] = UIParent
		f:SetPoint(unpack(DartSettings.setpoint))
		f:EnableMouse(true)
		f:RegisterForDrag("LeftButton")
		f:SetMovable(true) -- Create frame before PLAYER_LOGIN to save position
		f:SetClampedToScreen(true)
		f:SetScript("OnDragStart", function(self) self:StartMoving() end)
		f:SetScript("OnDragStop", function(self)
			self:StopMovingOrSizing() 
			local p, r, t, x, y = self:GetPoint(1)
			local s = DartSettings.setpoint
			s[1] = p
			s[2] = nil
			s[3] = t or p
			s[4] = x or 0
			s[5] = y or 0
		end)
		f.Close = CreateFrame("Button", "$parenClose", f, "DiscordLib_CloseButtonTemplate")
		f.Close:SetSize(30, 30)
		f.Close:ClearAllPoints()
		f.Close:SetPoint("RIGHT", 0, 0)
		f.Close:SetScript("OnClick", function(self) self:GetParent():Hide() end)
		f.Options = {}
	else
		f:SetWidth(parent:GetWidth())
		f:SetHeight(height)
	end
	return f
end

local function PanelDisplay()
	local self = DART_Options_WorldView
	local AttachTo = self
	for i= 1, #self.Shown do
		if self.Shown[i] then
			self.Panels[i]:ClearAllPoints()
			self.Panels[i]:SetPoint("TOP", AttachTo, "BOTTOM")
			self.Panels[i]:Show()
			AttachTo = self.Panels[i]
		else
			self.Panels[i]:Hide()
		end
	end
end

local function CreateOption(name, parent, id, text, height)
	local f = CreateFrame("CheckButton", "$parentButton"..name, parent)--, "UIPanelButtonTemplate")
	f:SetNormalTexture("Interface\\Buttons\\UI-PageButton-Background")
	f:GetNormalTexture():SetAlpha(0.5)
	f:SetPushedTexture("Interface\\QuestFrame\\UI-QuestItemNameFrame")
	f:SetCheckedTexture("Interface\\Buttons\\UI-PageButton-Background")
	f:SetHighlightTexture("Interface\\Buttons\\UI-Common-MouseHilight")
	f:SetSize(18, 18)
--	f:SetFrameLevel(6)
	f.Id = id
	parent.Shown[f.Id] = false
	f.Text = f:CreateFontString("BORDER")
	f.Text:SetPoint("CENTER")
	f.Text:SetFontObject(GameFontNormal)
	f.Text:SetTextColor(0.8, 0.5, 0)
	f.Text:SetText(text)
	parent.Panels[id] = CreateBackground("Interface\\DialogFrame\\UI-DialogBox-Background", "$parentPanel", parent, height)
	f.Panel = parent.Panels[id]
--	f.Panel:SetFrameLevel(6)

	f.Panel.Divider = f.Panel:CreateLine()
	f.Panel.Divider:SetThickness(1)
	f.Panel.Divider:SetStartPoint("TOPLEFT", f.Panel, 30, -2)
	f.Panel.Divider:SetEndPoint("TOPRIGHT", f.Panel, -30, -2)
	f.Panel.Divider:SetColorTexture(0.5, 0.5, 0.5)
	f.Panel.Text = f.Panel:CreateFontString("BORDER")
	f.Panel.Text:SetPoint("TOP", 0, -3)
	f.Panel.Text:SetFontObject(GameFontNormal)
	f.Panel.Text:SetTextColor(0.8, 0.5, 0)
	f.Panel.Text:SetText(text)
	parent.Panels[id]:Hide()
	f:SetScript("OnClick", function(self)
		local Shown = self:GetParent().Shown
		Shown[self.Id] = self:GetChecked()
		PanelDisplay()
	end)
	f:ClearAllPoints()
	return f
end

local function ShowWorldView(wvButton)
	local f = DART_Options_WorldView
	if not f then
		f = CreateBackground("Interface\\DialogFrame\\UI-DialogBox-Background-Dark", "DART_Options_WorldView", UIParent, 28, 245)
		f:SetFrameStrata(HighStrata)
		f:SetFrameLevel(6)
		
		f:SetScript("OnHide", WorldViewOnHide)
		f:SetScript("OnShow", WorldViewOnShow)
		
		f.Pin = CreateFrame("CheckButton", "$parentButtonPin", f)
		f.Pin:SetNormalTexture("Interface\\Buttons\\UI-PageButton-Background")
		f.Pin:GetNormalTexture():SetAlpha(0.5)
		f.Pin:SetPushedTexture("Interface\\QuestFrame\\UI-QuestItemNameFrame")
		f.Pin:SetCheckedTexture("Interface\\Buttons\\UI-PageButton-Background")
		f.Pin:SetHighlightTexture("Interface\\Buttons\\UI-Common-MouseHilight")
		f.Pin.OverLay = f.Pin:CreateTexture()
		f.Pin.OverLay:SetAllPoints()
		f.Pin.Unpinned = "Interface\\AddOns\\"..AddonName.."\\Unpinned"
		f.Pin.Pinned = "Interface\\AddOns\\"..AddonName.."\\Pinned"
		f.Pin.OverLay:SetTexture(f.Pin.Unpinned)
		f.Pin:SetSize(18, 18)
		f.Pin:SetPoint("RIGHT", f.Close, "LEFT", -2, 0)
		f.Pin:SetScript("OnClick", function(self)
			if self:GetChecked() then
				self.OverLay:SetTexture(self.Pinned)
				WorldViewOnHide(self:GetParent(), true)
				local f = self:GetParent().ToggleMovers
				f:SetEnabled(false)
				f:SetChecked(false)
				f:GetScript("OnClick")(f)
			else
				self.OverLay:SetTexture(self.Unpinned)
				WorldViewOnShow(self:GetParent())
				local f = self:GetParent().ToggleMovers
				f:SetEnabled(true)
				f:SetChecked(false)
				f:GetScript("OnClick")(f)
			end
		end)

		f.Logo = f:CreateTexture("$parentLogo")
		f.Logo:SetSize(20, 20)
--		f.Logo:SetPoint("RIGHT", f.Close, "LEFT", -2, 0)
		f.Logo:SetPoint("RIGHT", f.Pin, "LEFT", -2, 0)
		f.Logo:SetTexture("Interface\\AddOns\\"..AddonName.."\\WorldView")

	
		f.Title = f:CreateFontString("$parentTitle")
		f.Title:SetFontObject(GameFontNormal)
		f.Title:SetJustifyH("CENTER")
--		f.Title:SetJustifyV("CENTER")
		f.Title:SetJustifyV("MIDDLE")
		f.Title:SetTextColor(0.9, 0.6, 0)
		f.Title:SetText("Discord Art")
		f.Title:SetPoint("TOP", 0, -2)

		f.Profile = f:CreateFontString("$parentProfile")
		f.Profile:SetFontObject(GameFontNormalSmall)
		f.Profile:SetJustifyH("CENTER")
--		f.Profile:SetJustifyV("CENTER")
		f.Profile:SetJustifyV("MIDDLE")
		f.Profile:SetTextColor(1, 1, 1)
		f.Profile:SetPoint("TOP", f.Title, "BOTTOM", 0, 0)
		SetProfileText(f)

		f.Shown = {} -- 1=Grid, 2=GridOptions, 3=ViewPort for the widgets on panels 1 & 2
		f.Panels = {}
		f.ToggleGrid = CreateOption("Grid", f, 1, "#", 45) 
		f.ToggleGrid:SetPoint("LEFT", f, 2, 0)
		AzGridInitialise(f.ToggleGrid.Panel, f.ToggleGrid, DartSettings.grid, DART_TEXT.gridtooltips, TopLeft)

		f.ToggleOptions = CreateOption("Options", f, 2, "*", 45) 
		f.ToggleOptions:SetPoint("LEFT", f.ToggleGrid, "RIGHT", 2, 0)
		AzGridOptionsInitialise(f.ToggleOptions.Panel, f.ToggleGrid.Panel, DartSettings.grid, DART_TEXT.gridtooltips, Defaults.WorldViewFrame.grid, GridOptionsTopLeft)

		f.ToggleMovers = CreateOption("ViewPort", f, 3, "<>", 150) 
		f.ToggleMovers:SetPoint("LEFT", f.ToggleOptions, "RIGHT", 2, 0)
		MoveDartOptions(f)
		
--		f.ToggleViewPort = CreateOption("ViewPort", f, 4, "<>", 50) 
--		f.ToggleViewPort:SetPoint("LEFT", f.ToggleOptions, "RIGHT", 2, 0)
--		AddViewPortControls(f.ToggleViewPort)
		
		wvButton:GetParent():Hide()
	end
--	DART_TextureOptions_NudgeIndex.value = 1 -- Set move anchor to 1
--	DART_Options_SelectNudgeIndex(DART_TextureOptions_NudgeIndex)
--	DL_Show_Menu(DART_TextureOptions_NudgeIndex_Button, 1)
	f.Pin:SetChecked(false)
	f.Pin:GetScript("OnClick")(f.Pin)
	f:Show()
	wvButton:SetChecked(false)
--	wvButton:GetParent():Hide()
end

WVButton = CreateFrame("CheckButton", "$parentWorldView", DART_Options, "UIPanelButtonTemplate")
WVButton:SetSize(24, 24)
WVButton:SetPoint("TOPRIGHT", DART_Options_CloseButton, "BOTTOM", 10, -30)
WVButton:SetNormalTexture("Interface\\AddOns\\"..AddonName.."\\WorldView")
WVButton:SetNormalTexture("Interface\\AddOns\\"..AddonName.."\\WorldView")
WVButton:SetCheckedTexture("Interface\\AddOns\\"..AddonName.."\\WorldView")
WVButton:SetScript("OnClick", function(self)
	if self:GetChecked() then
		ShowWorldView(self)
	end
end)
WVButton:SetScript("OnEnter", function(self)
	GameTooltip:SetOwner(self, "ANCHOR_LEFT")
	GameTooltip:SetText(DART_TEXT.WorldView)	
end)
WVButton:SetScript("OnLeave", function(self)
	GameTooltip:Hide()
end)

DART_Options_CloseButton:HookScript("OnClick", function(self)
	if DART_Options_WorldView then
		DART_Options_WorldView:Hide()
	end
	if WVButton:GetChecked() then
		WVButton:SetChecked(false)
	end
	if self:GetParent():IsShown() then
		self:GetParent():Hide()
	end
end)